 

> 🚧 Avertissement
>
> Il s’agit d’une version de développement. Des modifications sur les
> fonctions peuvent intervenir.
>
> Consultez l’article
> [Changements]()
> pour plus d’informations.

# Présentation du package

Grâce au package `apifoncier`, vous pouvez interroger les
différentes bases de données foncières produites par le Cerema et la
DGALN directement depuis `python` ! *Une partie des données est interrogeable
uniquement avec un accès restreint lié à vos droits. Pensez à vous
rendre sur
[ConsultDF](https://consultdf.cerema.fr/consultdf/services/apidf) pour
obtenir un accès.

# Installation

``` python
pip install apifoncier
```

# Fonctions et données disponibles

Vous trouverez ci-dessous l’ensemble des informations sur les jeux de
données disponibles grâce à ce package. N’hésitez pas à parcourir
l’ensemble des articles de la documentation ainsi que les pages dédiées
à chaque fonction.

Retrouvez également des fonctions de valorisation des données telles que
des [graphiques](), [cartographies dynamiques]() ou encore [tableaux]().


## Indicateurs de consommation d’espace (accès libre)

Le package `apifoncier` permet d’interroger l’ensemble du territoire
français afin d’obtenir les indicateurs de consommation d’espace pour la
période comprise entre une deux années à l’échelle communale ou
départementale.

**Plus d’informations sur les fonctions disponibles en allant l’[article
dédidé]()**

## Indicateurs de prix (accès libre)


## Cartofriches (accès libre)

**Plus d’informations sur les fonctions disponibles en allant sur
l’[article dédié]()**

## DVF+ (accès libre)

**Plus d’informations sur les fonctions disponibles en allant sur
l’[article dédié]()**

## DV3F (accès restreint)

**Plus d’informations sur les fonctions disponibles en allant sur
l’[article dédié]().**

## Fichiers fonciers (accès restreint)

**Plus d’informations sur les fonctions disponibles en allant sur
l’[article dédié]().**

# Ressources

Pour retrouver toutes les informations sur les données foncières :
[datafoncier.cerema.fr](datafoncier.cerema.fr)

Dictionnaire et documentation sur toutes les variables :
[doc-datafoncier.cerema.fr](doc-datafoncier.cerema.fr)

[Pour en savoir plus sur l’API données foncières du
cerema.](https://apidf-preprod.cerema.fr/swagger/)
